# earningtrader
A trading platform based on the Reinforcement Learning framework

## Getting Started
- TBA

## Overview

### Project Architecture
There are five main components in the project. Please refer to the image below:

![](./docs/image/rl-trader.drawio.svg)

- TBA
